@@ -2,7 +2,7 @@ package SWISH::Prog::KSx::InvIndex;
 use strict;
 use warnings;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use base qw( SWISH::Prog::InvIndex );
 
@@ -21,6 +21,9 @@ class for Swish3.
 
 =head1 METHODS
 
+Only new and overridden methods are documented here. See
+the L<SWISH::Prog::Indexer> documentation.
+
 None overridden at this time.
 
 =cut
@@ -50,6 +53,10 @@ You can also look for information at:
 
 =over 4
 
+=item * Mailing list
+
+L<http://lists.swish-e.org/listinfo/users>
+
 =item * RT: CPAN's request tracker
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=SWISH-Prog-KSx>
