@@ -2,7 +2,7 @@ package SWISH::Prog::KSx::Results;
 use strict;
 use warnings;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use base qw( SWISH::Prog::Results );
 use SWISH::Prog::KSx::Result;
@@ -24,6 +24,9 @@ class for Swish3.
 
 =head1 METHODS
 
+Only new and overridden methods are documented here. See
+the L<SWISH::Prog::Results> documentation.
+
 =head2 next
 
 Returns the next SWISH::Prog::KSx::Result object from the result set.
@@ -69,6 +72,10 @@ You can also look for information at:
 
 =over 4
 
+=item * Mailing list
+
+L<http://lists.swish-e.org/listinfo/users>
+
 =item * RT: CPAN's request tracker
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=SWISH-Prog-KSx>
